.. -------------------------------------------------------------------------------------
.. Note:
..     This is a documentation source file for Graph Transliterator.
..     Certain links and other features will not be accessible from here.
.. Links:
..     - Documentation: https://graphtransliterator.readthedocs.org
..     - PyPI: https://pypi.org/project/graphtransliterator/
..     - Repository: https://github.com/seanpue/graphtransliterator/
.. -------------------------------------------------------------------------------------

.. highlight:: shell

============
Installation
============


Stable release
--------------

To install Graph Transliterator, run this command in your terminal:

.. code-block:: console

    $ pip install graphtransliterator

This is the preferred method to install Graph Transliterator, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for Graph Transliterator can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/seanpue/graphtransliterator

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/seanpue/graphtransliterator/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/seanpue/graphtransliterator
.. _tarball: https://github.com/seanpue/graphtransliterator/tarball/master

Required modules
----------------

Graph Transliterator requires three Python modules, `click`_, `marshmallow`_ and
`pyyaml`_. These modules will be installed automatically using the methods described
above.

.. _click: https://pypi.org/project/click/
.. _marshmallow: https://pypi.org/project/marshmallow/
.. _pyyaml: https://pypi.org/project/PyYAML/
